@@ -58,7 +58,7 @@ new S3ToStepFunction(scope: Construct, id: string, props: S3ToStepFunctionProps)
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|existingBucketObj?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
+|existingBucketObj?|[`s3.IBucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.IBucket.html)|Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.|
 |bucketProps?|[`s3.BucketProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.BucketProps.html)|User provided props to override the default props for the S3 Bucket.|
 |stateMachineProps|[`sfn.StateMachineProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachineProps.html)|Optional user provided props to override the default props for sfn.StateMachine|
 |eventRuleProps?|[`events.RuleProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-events.RuleProps.html)|Optional user provided eventRuleProps to override the defaults|
@@ -71,7 +71,7 @@ new S3ToStepFunction(scope: Construct, id: string, props: S3ToStepFunctionProps)
 |stateMachine|[`sfn.StateMachine`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-stepfunctions.StateMachine.html)|Returns an instance of sfn.StateMachine created by the construct|
 |stateMachineLogGroup|[`logs.LogGroup`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-logs.LogGroup.html)|Returns an instance of the LogGroup created by the construct for StateMachine|
 |cloudwatchAlarms|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
-|s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
+|s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
 |s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 |cloudtrail|[`cloudtrail.Trail`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudtrail.Trail.html)|Returns an instance of the cloudtrail.Trail created by the construct|
 |cloudtrailBucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct for CloudTrail|
@@ -147,7 +147,7 @@ class S3ToStepFunction(
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         deploy_cloud_trail: typing.Optional[bool] = None,
         event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         """
         :param scope: - represents the scope for all the resources.
@@ -180,11 +180,6 @@ class S3ToStepFunction(
     def cloudwatch_alarms(self) -> typing.List[aws_cdk.aws_cloudwatch.Alarm]:
         return jsii.get(self, "cloudwatchAlarms")
 
-    @builtins.property
-    @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> aws_cdk.aws_s3.Bucket:
-        return jsii.get(self, "s3Bucket")
-
     @builtins.property
     @jsii.member(jsii_name="stateMachine")
     def state_machine(self) -> aws_cdk.aws_stepfunctions.StateMachine:
@@ -210,6 +205,11 @@ class S3ToStepFunction(
     def cloudtrail_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "cloudtrailLoggingBucket")
 
+    @builtins.property
+    @jsii.member(jsii_name="s3Bucket")
+    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+        return jsii.get(self, "s3Bucket")
+
     @builtins.property
     @jsii.member(jsii_name="s3LoggingBucket")
     def s3_logging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
@@ -235,7 +235,7 @@ class S3ToStepFunctionProps:
         bucket_props: typing.Optional[aws_cdk.aws_s3.BucketProps] = None,
         deploy_cloud_trail: typing.Optional[bool] = None,
         event_rule_props: typing.Optional[aws_cdk.aws_events.RuleProps] = None,
-        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.Bucket] = None,
+        existing_bucket_obj: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         """
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
@@ -304,7 +304,7 @@ class S3ToStepFunctionProps:
         return self._values.get("event_rule_props")
 
     @builtins.property
-    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
+    def existing_bucket_obj(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
         """Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
 
         default
